@@ -96,17 +96,27 @@ static void lacpdu_init(struct lacpdu *lacpdu)
 
 static bool lacpdu_check(struct lacpdu *lacpdu)
 {
+	/*
+	 * According to Annex 43B, section 4, aside from LACP, the Slow
+	 * Protocol linktype is also to be used by other protocols, like
+	 * 0x02 for LAMP, 0x03 for OAM. So for none LACP protocols, just
+	 * silence ignore.
+	 */
+	if (lacpdu->subtype != 0x01)
+		return false;
+
 	/*
 	 * According to 43.4.12 version_number, tlv_type and reserved fields
 	 * should not be checked.
 	 */
 
-	if (lacpdu->subtype		!= 0x01 ||
-	    lacpdu->actor_info_len	!= 0x14 ||
+	if (lacpdu->actor_info_len	!= 0x14 ||
 	    lacpdu->partner_info_len	!= 0x14 ||
 	    lacpdu->collector_info_len	!= 0x10 ||
-	    lacpdu->terminator_info_len	!= 0x00)
+	    lacpdu->terminator_info_len	!= 0x00) {
+		teamd_log_warn("malformed LACP PDU came.");
 		return false;
+	}
 	return true;
 }
 
@@ -996,8 +1006,7 @@ static int lacp_port_set_state(struct lacp_port *lacp_port,
 		return err;
 
 	lacp_port_actor_update(lacp_port);
-	if (lacp_port->periodic_on)
-		return 0;
+
 	return lacpdu_send(lacp_port);
 }
 
@@ -1089,10 +1098,8 @@ static int lacpdu_recv(struct lacp_port *lacp_port)
 	if (!teamd_port_present(lacp_port->ctx, lacp_port->tdport))
 		return 0;
 
-	if (!lacpdu_check(&lacpdu)) {
-		teamd_log_warn("malformed LACP PDU came.");
+	if (!lacpdu_check(&lacpdu))
 		return 0;
-	}
 
 	/* Check if we have correct info about the other side */
 	if (memcmp(&lacpdu.actor, &lacp_port->partner,
@@ -1110,9 +1117,10 @@ static int lacpdu_recv(struct lacp_port *lacp_port)
 	if (err)
 		return err;
 
+	lacp_port_actor_update(lacp_port);
+
 	/* Check if the other side has correct info about us */
-	if (!lacp_port->periodic_on &&
-	    memcmp(&lacpdu.partner, &lacp_port->actor,
+	if (memcmp(&lacpdu.partner, &lacp_port->actor,
 		   sizeof(struct lacpdu_info))) {
 		err = lacpdu_send(lacp_port);
 		if (err)
